; This file is generated by the program tools/tools/html-mirroring-from-dtd/laml-mirror-via-dtd.scm. Do not edit!

;;;; This is an accurate mirror of HTML 4.0 (loose) on surface form. A surface form has a very flexible syntactic composition. Use the surface forms when you write an HTML document in LAML syntax. Each function in this file mirrors and generates an HTML tag. The general form of a surface mirror function is <pre>   (tag 'a1 "v1" 'a2 "v2" ... 'am "vm" contents-1 contents-2 ... contents-n). </pre>where, in the most common case, <kbd>contents-1</kbd>, <kbd>contents-2</kbd> through <kbd>contents-n</kbd> are strings (verbatim or the result of other mirror functions) which are string-appended to form the contents of the element. <p>From LAML version 16.2 <kbd>contents-i</kbd> (i from 1 to n) can also be flat, proper lists of strings which automatically are string-appended  to form a single content string. From LAML version 17.0, the mirror functions accept lists nested to an arbitrary level. Such lists are processed recursively. It means that you can pass lists of content constituents, or even lists with attribute names and values to the mirror functions.<p>The attribute names must be symbols, and the attribute values have to be strings.<p>The expression from above corresponds to the HTML tag <pre>   &lt;tag a1 "v1" a2 "v2" ... am "vm"&gt; contents-1 contents-2 ... contents-n &lt;/tag&gt;</pre>In the Scheme form it is even possible to have attributes between and after the textual content. Attributes prefixed with 'css:' are CSS style attributes.<p>Unless stated otherwise there will be a space character between contents strings, such as in between <kbd>contents-1</kbd> and <kbd>contents-2</kbd>. A boolean value false in between the contents strings, such as between <kbd>contents-1</kbd> and <kbd>contents-2</kbd>, suppresses white space in between them. This is in particular useful before punctuation characters. We recommend that you bind #f to a notationally convenient variable such as '_'. <p>If the boolean variable <kbd>check-html-attributes?</kbd> is true the functions check the attributes of the tag against the attribute definitions in the document type definition. <p>The HTML mirror functions emit non-pretty printed HTML code. If you want pretty printed HTML you can use the <a href = "../../../tools/xml-html-support/man/html-support.html">HTML pretty printer</a>, which is part of the LAML software package. See also the <a href = "../../../man/laml.html#html-pp">html-pp</a> procedure. Notice that pretty printing may be quite expensive compared with the generation as such.<p>This library requries the general library and the accompanying basic form library. <p>Notice that the function map and the HTML element map give a name collision.We prefix the HTML element with 'html:' when applied as a HTML mirror function in LAML.<p>This library provides links to the <a href = "../../../html-doc/html401/cover.html">W3 document which defines the HTML tags</a>. The underlying WWW pages are supplied as part of the LAML software bundle.<p>See also the <a href = "basis.html">basic form library</a> of the mirror and the HTML <a href = "convenience.html">convenience library</a>.<p><b><em>This library is obsolete for development of new stuff</em></b>. Use a validating mirror instead!

; Constants:

(define explicit-space #t)
(define explicit-space-suppress #f)

;; The symbolic name of explicit white space suppress
(define _ explicit-space-suppress)



; ---------------------------------------------------------------------------------------------------------------

; Return an HTML mirror surface function, in which textual content parameters and attribute
; value pairs can be given in a very liberal fashion.
; html-basic-function is the name of an HTML basic mirror function to be called once we have
; sorted out contents and attributes of the present form.
; Tag-name is a string which represents the name of the tag (used for error message purposes).
; single-double-kind is either the symbol single, double or possible-single.
; The generated surface function is made efficient (avoiding parameter sorting) in the following special cases:
; (1) single-tag, no attributes.
; (2) double-tag, one string contents parameter.
(define (generate-html-surface-function html-basic-function tag-name single-double-kind)
 (cond ((eq? single-double-kind 'double)
          (lambda parameters
            (if (and (pair? parameters) (string? (car parameters)) (null? (cdr parameters)))
                (apply html-basic-function (cons (car parameters) '())) ; efficient handling of double tag with 
                                                                        ; a single string contents parameter
                (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
		       (contents (car contents-attributes))
		       (attributes (cdr contents-attributes))
                      )
		  (apply html-basic-function (cons contents attributes)))
            )
          )
       )

       ((eq? single-double-kind 'single)   
          (lambda parameters
            (if (null? parameters)
                (apply html-basic-function '())  ; efficient handling of single tag with no attributes
                (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
		       (contents (car contents-attributes))
		       (attributes (cdr contents-attributes))
                      )
		  (check-for-empty-contents! contents tag-name)
		  (apply html-basic-function attributes))
            )
          )
       )

       ((eq? single-double-kind 'possible-single)   
          (lambda parameters
            (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
                   (contents (car contents-attributes))
                   (attributes (cdr contents-attributes))
                  )
               (if (empty-string? contents) ; generate single tag
                   (apply html-basic-function (cons #f attributes))
                   (apply html-basic-function (cons contents attributes))
               )
            )
          )
       )

       (else (error (string-append "generate-html-surface-function: unknown single-double-kind: " (as-string single-double-kind))))
 )
)

; Previous less efficient version:
; (define (generate-html-surface-function html-basic-function tag-name single-double-kind)
;   (lambda parameters
;    (let* ((contents-attributes (sort-tag-parameters parameters tag-name))
;           (contents (car contents-attributes))
;           (attributes (cdr contents-attributes)))
;      (cond ((eq? single-double-kind 'double)
;                (apply html-basic-function (cons contents attributes)))
;            ((and (eq? single-double-kind 'possible-single) (empty-string? contents))  ; generate single tag
;                (apply html-basic-function (cons #f attributes)))
;            ((and (eq? single-double-kind 'possible-single) (not (empty-string? contents)))  ; generate double tag
;                (apply html-basic-function (cons contents attributes)))
;            (else 
;              (begin
;                (check-for-empty-contents! contents tag-name)
;                (apply html-basic-function attributes)))))))

(define (check-for-empty-contents! contents tag-name)
  (if (not (empty-string? contents))
      (display-warning (string-append "The single tag " tag-name " is not supposed to have any contents: " contents ". We just skip it."))))

; Return a pair of contents string and a property list of attributes from parameters.
(define (sort-tag-parameters parameters tag-name)
 (sort-tag-parameters-1 parameters parameters "" '() tag-name))

; Process the parameters iteratively.
; Handle boolean values: Boolean #f suppress interspacing. Boolean #t or no boolean value adds interspacing.
; Also collect attribute keys and values.
; Lists are unfolded and processed recursively to an arbitrary depth.
; The parameters contents and attributes are used to accumulate the results, tail recursively.
; tag-name is the name of the surrounding element, used for error message purposes.
; original-parameters are carried through the recursive call, and also used for error message purposes.
(define (sort-tag-parameters-1 original-parameters parameters contents attributes tag-name)
  (cond ((null? parameters) (cons (strip-trailing-characters (list #\space) contents) (reverse attributes)))
        
        ; STRING, no space after
        ((and (string? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (not (cadr parameters)))  
                 (sort-tag-parameters-1 original-parameters (cddr parameters) (string-append contents (car parameters)) attributes tag-name))

        ; STRING: space after - necessary?
        ((and (string? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (cadr parameters))        
                 (sort-tag-parameters-1 original-parameters
                                        (cddr parameters) (string-append contents (car parameters) " " ) attributes tag-name))

        ; STRING - space after
        ((string? (car parameters))   
                 (sort-tag-parameters-1 original-parameters 
                                        (cdr parameters) (string-append contents (car parameters) " ") attributes tag-name))

        ; LIST - no space after, i.e. suppress space
        ((and (list? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (not (cadr parameters)))
           (let* ((rec-res (sort-tag-parameters-1 original-parameters (car parameters) "" '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )
             (sort-tag-parameters-1 original-parameters
				    (cddr parameters) 
				    (string-append contents rec-contents) (append (reverse rec-attributes) attributes) tag-name)))

        ; LIST - space after - necessary?
        ((and (list? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters))  (cadr parameters))  
           (let* ((rec-res (sort-tag-parameters-1 original-parameters (car parameters) "" '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )
              (if (not (null? rec-attributes)) (set! husk rec-attributes))
              (sort-tag-parameters-1 original-parameters
				     (cddr parameters) 
				     (string-append contents rec-contents " " ) (append (reverse rec-attributes) attributes) tag-name)))

        ; LIST - space after
        ((and (list? (car parameters))) 
           (let* ((rec-res (sort-tag-parameters-1 original-parameters (car parameters) "" '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )
             (sort-tag-parameters-1 original-parameters
				    (cdr parameters) 
				    (string-append contents rec-contents " " ) (append (reverse rec-attributes) attributes) tag-name)))

        ; SYMBOL - attribute name
        ((and (symbol? (car parameters)) (not (null? (cdr parameters))) (not (boolean? (cadr parameters))))
           (let ((attr-name (car parameters))
                 (attr-val (cadr parameters)))
             (sort-tag-parameters-1 original-parameters (cddr parameters) contents (cons attr-val (cons attr-name attributes)) tag-name)))

        ; SYMBOL - error
        ((symbol? (car parameters)) (sort-error (string-append "Attributes of the " tag-name
                                    " tag must be of the form 'symbol \"value\". Only the symbol " (as-string (car parameters))
                                    " appears in last attribute") original-parameters))

        (else (sort-error (string-append "Error in an LAML " tag-name " tag.") original-parameters))
  ))

; Return the string corresponding to the element contents of lst.
; As of this version, no kinds of white space is added automatically.
; Not used anymore
(define (list-to-element-contents lst)
  (apply string-append lst))

(define (sort-error message parameters)
 (let* ((max-str-lgt 80)  ; symbolic constant definition
        (parameters-1 (as-quoted-string parameters))
        (parameters-2 (if (> (string-length parameters-1) max-str-lgt) 
                        (string-append (substring parameters-1 0 (- max-str-lgt 1)) "...")
                        parameters-1)))
  (error
    (string-append
      message (as-string #\newline)
      "  FORM CONTENTS AND ATTR.: " parameters-2 (as-string #\newline)))))
      

;;; Other useful functions. 
;;; In this section there are non-mirror functions which are useful in surface HTML forms.

;; A non-HTML tag which concatenates parameters of a form to a single string. 
;; There may be boolean values among the parameters.
;; A boolean false after a textual contents string suppresses white space after the contents string.
;; Warn if there are attributes among the parameters. Possible attributes are just skipped.
(define (concatenate . parameters)
  (let* ((res-pair (sort-tag-parameters parameters "concatenate function"))
         (contents (car res-pair))
         (attributes (cdr res-pair)))
    (if (not (null? attributes))
        (display-warning 
          (string-append "There are attribute value pairs in a context assumed to pure textual contents: " (as-string attributes) ". "
                         "I just discarded these.")))
    contents))
 

; Strip trailing space - only one space character is stripped.
; Not used any more
(define (strip-trailing-space str)
 (let ((lgt (string-length str)))
  (cond ((empty-string? str) "")
        ((eq? (string-ref str (- lgt 1)) #\space)  ; last character is space
          (substring str 0 (- lgt 1)))
        (else str))))

;; Generate a HTML tag application for tag-name with attributes and contents
;; given by parameters. The parameters obeys the syntax of a the LAML surface forms.
;; This function is useful for generation of non-standard tag applications.
(define (free-html-element tag-name . parameters)
 (let* ((cont-attr (sort-tag-parameters parameters tag-name))
        (cont (car cont-attr))
        (attr (cdr cont-attr)))
   (if (empty-string? cont)
       (itag1 tag-name attr)
       (itag tag-name cont attr))))

;; Generate a HTML tag application for tag-name with attributes and contents given by parameters.
;; This function corresponds exactly to free-html-element; however, this function takes exactly two
;; parameters whereas free-html-elements takes one or more parameters.
(define (free-html-element-1 tag-name parameters)
 (let* ((cont-attr (sort-tag-parameters parameters tag-name))
        (cont (car cont-attr))
        (attr (cdr cont-attr)))
   (if (empty-string? cont)
       (itag1 tag-name attr)
       (itag tag-name cont attr))))

;; Define partial attributes and element contents of element and return a new element function
;; with the attributes and contents partially fixed.
;; attributes-and-contents is of the same form as the parameters to a LAML surface mirror functions.
;; In fact, attributes-and-contents are just appended to the actual parameters to the modified.
;; .example (define a-main (modify-element a 'target "main"))
;; .returns an attribute-modified mirror function
(define (modify-element element . attributes-and-contents)
  (lambda parameters (apply element (append parameters attributes-and-contents))))

;;; The HTML surface mirror functions

;; The LAML mirror of the HTML 4.0 (loose) <b>HTML</b> tag element which can be applied without contents (corresponding to start tag only) (document root element ). <br>
;; .form (html . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: lang, dir, version. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:html" "basis.html#html4:html"
;; .reference "HTML documentation" "HTML" "../../../html-doc/html401/struct/global.html#edef-HTML"
(define html (generate-html-surface-function html4:html "html" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>NOSCRIPT</b> double tag element (alternate content container for non script-based rendering ). <br>
;; .form (noscript . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:noscript" "basis.html#html4:noscript"
;; .reference "HTML documentation" "NOSCRIPT" "../../../html-doc/html401/interact/scripts.html#edef-NOSCRIPT"
(define noscript (generate-html-surface-function html4:noscript "noscript" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SCRIPT</b> double tag element (script statements ). <br>
;; .form (script . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: type. <p>Optional attributes: charset, language, src, defer, event, for. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:script" "basis.html#html4:script"
;; .reference "HTML documentation" "SCRIPT" "../../../html-doc/html401/interact/scripts.html#edef-SCRIPT"
(define script (generate-html-surface-function html4:script "script" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>STYLE</b> double tag element (style info ). <br>
;; .form (style . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: type. <p>Optional attributes: lang, dir, media, title. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:style" "basis.html#html4:style"
;; .reference "HTML documentation" "STYLE" "../../../html-doc/html401/present/styles.html#edef-STYLE"
(define style (generate-html-surface-function html4:style "style" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>META</b> single tag element (generic metainformation ). <br>
;; .form (meta . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: content. <p>Optional attributes: lang, dir, http-equiv, name, scheme. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:meta" "basis.html#html4:meta"
;; .reference "HTML documentation" "META" "../../../html-doc/html401/struct/global.html#edef-META"
(define meta (generate-html-surface-function html4:meta "meta" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BASE</b> single tag element (document base URI ). <br>
;; .form (base . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: href, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:base" "basis.html#html4:base"
;; .reference "HTML documentation" "BASE" "../../../html-doc/html401/struct/links.html#edef-BASE"
(define base (generate-html-surface-function html4:base "base" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>ISINDEX</b> single tag element (single line prompt ). <br>
;; .form (isindex . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, prompt. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:isindex" "basis.html#html4:isindex"
;; .reference "HTML documentation" "ISINDEX" "../../../html-doc/html401/interact/forms.html#edef-ISINDEX"
(define isindex (generate-html-surface-function html4:isindex "isindex" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TITLE</b> double tag element (document title ). <br>
;; .form (title . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: lang, dir. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:title" "basis.html#html4:title"
;; .reference "HTML documentation" "TITLE" "../../../html-doc/html401/struct/global.html#edef-TITLE"
(define title (generate-html-surface-function html4:title "title" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>HEAD</b> tag element which can be applied without contents (corresponding to start tag only) (document head ). <br>
;; .form (head . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: lang, dir, profile. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:head" "basis.html#html4:head"
;; .reference "HTML documentation" "HEAD" "../../../html-doc/html401/struct/global.html#edef-HEAD"
(define head (generate-html-surface-function html4:head "head" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>NOFRAMES</b> double tag element (alternate content container for non frame-based rendering ). <br>
;; .form (noframes . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:noframes" "basis.html#html4:noframes"
;; .reference "HTML documentation" "NOFRAMES" "../../../html-doc/html401/present/frames.html#edef-NOFRAMES"
(define noframes (generate-html-surface-function html4:noframes "noframes" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>IFRAME</b> double tag element (inline subwindow ). <br>
;; .form (iframe . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, longdesc, name, src, frameborder, marginwidth, marginheight, scrolling, align, height, width. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:iframe" "basis.html#html4:iframe"
;; .reference "HTML documentation" "IFRAME" "../../../html-doc/html401/present/frames.html#edef-IFRAME"
(define iframe (generate-html-surface-function html4:iframe "iframe" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>FRAME</b> single tag element (subwindow ). <br>
;; .form (frame . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, longdesc, name, src, frameborder, marginwidth, marginheight, noresize, scrolling. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:frame" "basis.html#html4:frame"
;; .reference "HTML documentation" "FRAME" "../../../html-doc/html401/present/frames.html#edef-FRAME"
(define frame (generate-html-surface-function html4:frame "frame" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>FRAMESET</b> double tag element (window subdivision). <br>
;; .form (frameset . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, rows, cols, onload, onunload. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:frameset" "basis.html#html4:frameset"
;; .reference "HTML documentation" "FRAMESET" "../../../html-doc/html401/present/frames.html#edef-FRAMESET"
(define frameset (generate-html-surface-function html4:frameset "frameset" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TH</b> tag element which can be applied without contents (corresponding to start tag only) (table header cell, table data cell). <br>
;; .form (th . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign, nowrap, bgcolor, width, height. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:th" "basis.html#html4:th"
;; .reference "HTML documentation" "TH" "../../../html-doc/html401/struct/tables.html#edef-TH"
(define th (generate-html-surface-function html4:th "th" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TD</b> tag element which can be applied without contents (corresponding to start tag only) (table header cell, table data cell). <br>
;; .form (td . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, abbr, axis, headers, scope, rowspan, colspan, align, char, charoff, valign, nowrap, bgcolor, width, height. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:td" "basis.html#html4:td"
;; .reference "HTML documentation" "TD" "../../../html-doc/html401/struct/tables.html#edef-TD"
(define td (generate-html-surface-function html4:td "td" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TR</b> tag element which can be applied without contents (corresponding to start tag only) (table row ). <br>
;; .form (tr . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign, bgcolor. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:tr" "basis.html#html4:tr"
;; .reference "HTML documentation" "TR" "../../../html-doc/html401/struct/tables.html#edef-TR"
(define tr (generate-html-surface-function html4:tr "tr" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>COL</b> single tag element (table column ). <br>
;; .form (col . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:col" "basis.html#html4:col"
;; .reference "HTML documentation" "COL" "../../../html-doc/html401/struct/tables.html#edef-COL"
(define col (generate-html-surface-function html4:col "col" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>COLGROUP</b> tag element which can be applied without contents (corresponding to start tag only) (table column group ). <br>
;; .form (colgroup . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, span, width, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:colgroup" "basis.html#html4:colgroup"
;; .reference "HTML documentation" "COLGROUP" "../../../html-doc/html401/struct/tables.html#edef-COLGROUP"
(define colgroup (generate-html-surface-function html4:colgroup "colgroup" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TBODY</b> tag element which can be applied without contents (corresponding to start tag only) (table body ). <br>
;; .form (tbody . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:tbody" "basis.html#html4:tbody"
;; .reference "HTML documentation" "TBODY" "../../../html-doc/html401/struct/tables.html#edef-TBODY"
(define tbody (generate-html-surface-function html4:tbody "tbody" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TFOOT</b> tag element which can be applied without contents (corresponding to start tag only) (table footer ). <br>
;; .form (tfoot . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:tfoot" "basis.html#html4:tfoot"
;; .reference "HTML documentation" "TFOOT" "../../../html-doc/html401/struct/tables.html#edef-TFOOT"
(define tfoot (generate-html-surface-function html4:tfoot "tfoot" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>THEAD</b> tag element which can be applied without contents (corresponding to start tag only) (table header ). <br>
;; .form (thead . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, char, charoff, valign. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:thead" "basis.html#html4:thead"
;; .reference "HTML documentation" "THEAD" "../../../html-doc/html401/struct/tables.html#edef-THEAD"
(define thead (generate-html-surface-function html4:thead "thead" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>CAPTION</b> double tag element (table caption ). <br>
;; .form (caption . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:caption" "basis.html#html4:caption"
;; .reference "HTML documentation" "CAPTION" "../../../html-doc/html401/struct/tables.html#edef-CAPTION"
(define caption (generate-html-surface-function html4:caption "caption" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TABLE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (table . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, summary, width, border, frame, rules, cellspacing, cellpadding, align, bgcolor, datapagesize. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:table" "basis.html#html4:table"
;; .reference "HTML documentation" "TABLE" "../../../html-doc/html401/struct/tables.html#edef-TABLE"
(define table (generate-html-surface-function html4:table "table" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BUTTON</b> double tag element (push button ). <br>
;; .form (button . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, value, type, disabled, tabindex, accesskey, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:button" "basis.html#html4:button"
;; .reference "HTML documentation" "BUTTON" "../../../html-doc/html401/interact/forms.html#edef-BUTTON"
(define button (generate-html-surface-function html4:button "button" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>LEGEND</b> double tag element (fieldset legend ). <br>
;; .form (legend . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, accesskey, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:legend" "basis.html#html4:legend"
;; .reference "HTML documentation" "LEGEND" "../../../html-doc/html401/interact/forms.html#edef-LEGEND"
(define legend (generate-html-surface-function html4:legend "legend" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>FIELDSET</b> double tag element (form control group ). <br>
;; .form (fieldset . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:fieldset" "basis.html#html4:fieldset"
;; .reference "HTML documentation" "FIELDSET" "../../../html-doc/html401/interact/forms.html#edef-FIELDSET"
(define fieldset (generate-html-surface-function html4:fieldset "fieldset" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TEXTAREA</b> double tag element (multi-line text field ). <br>
;; .form (textarea . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: rows, cols. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, disabled, readonly, tabindex, accesskey, onfocus, onblur, onselect, onchange. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:textarea" "basis.html#html4:textarea"
;; .reference "HTML documentation" "TEXTAREA" "../../../html-doc/html401/interact/forms.html#edef-TEXTAREA"
(define textarea (generate-html-surface-function html4:textarea "textarea" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>OPTION</b> tag element which can be applied without contents (corresponding to start tag only) (selectable choice ). <br>
;; .form (option . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, selected, disabled, label, value. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:option" "basis.html#html4:option"
;; .reference "HTML documentation" "OPTION" "../../../html-doc/html401/interact/forms.html#edef-OPTION"
(define option (generate-html-surface-function html4:option "option" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>OPTGROUP</b> double tag element (option group ). <br>
;; .form (optgroup . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: label. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, disabled. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:optgroup" "basis.html#html4:optgroup"
;; .reference "HTML documentation" "OPTGROUP" "../../../html-doc/html401/interact/forms.html#edef-OPTGROUP"
(define optgroup (generate-html-surface-function html4:optgroup "optgroup" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SELECT</b> double tag element (option selector ). <br>
;; .form (select . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, name, size, multiple, disabled, tabindex, onfocus, onblur, onchange. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:select" "basis.html#html4:select"
;; .reference "HTML documentation" "SELECT" "../../../html-doc/html401/interact/forms.html#edef-SELECT"
(define select (generate-html-surface-function html4:select "select" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>INPUT</b> single tag element (form control ). <br>
;; .form (input . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, name, value, checked, disabled, readonly, size, maxlength, src, alt, usemap, tabindex, accesskey, onfocus, onblur, onselect, onchange, accept, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:input" "basis.html#html4:input"
;; .reference "HTML documentation" "INPUT" "../../../html-doc/html401/interact/forms.html#edef-INPUT"
(define input (generate-html-surface-function html4:input "input" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>LABEL</b> double tag element (form field label text ). <br>
;; .form (label . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, for, accesskey, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:label" "basis.html#html4:label"
;; .reference "HTML documentation" "LABEL" "../../../html-doc/html401/interact/forms.html#edef-LABEL"
(define label (generate-html-surface-function html4:label "label" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>FORM</b> double tag element (interactive form ). <br>
;; .form (form . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: action. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, method, enctype, onsubmit, onreset, target, accept-charset. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:form" "basis.html#html4:form"
;; .reference "HTML documentation" "FORM" "../../../html-doc/html401/interact/forms.html#edef-FORM"
(define form (generate-html-surface-function html4:form "form" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>LI</b> tag element which can be applied without contents (corresponding to start tag only) (list item ). <br>
;; .form (li . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, value. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:li" "basis.html#html4:li"
;; .reference "HTML documentation" "LI" "../../../html-doc/html401/struct/lists.html#edef-LI"
(define li (generate-html-surface-function html4:li "li" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DIR</b> double tag element (directory list, menu list ). <br>
;; .form (dir . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:dir" "basis.html#html4:dir"
;; .reference "HTML documentation" "DIR" "../../../html-doc/html401/struct/lists.html#edef-DIR"
(define dir (generate-html-surface-function html4:dir "dir" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>MENU</b> double tag element (directory list, menu list ). <br>
;; .form (menu . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:menu" "basis.html#html4:menu"
;; .reference "HTML documentation" "MENU" "../../../html-doc/html401/struct/lists.html#edef-MENU"
(define menu (generate-html-surface-function html4:menu "menu" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>UL</b> double tag element (unordered list ). <br>
;; .form (ul . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:ul" "basis.html#html4:ul"
;; .reference "HTML documentation" "UL" "../../../html-doc/html401/struct/lists.html#edef-UL"
(define ul (generate-html-surface-function html4:ul "ul" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>OL</b> double tag element (ordered list ). <br>
;; .form (ol . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, type, compact, start. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:ol" "basis.html#html4:ol"
;; .reference "HTML documentation" "OL" "../../../html-doc/html401/struct/lists.html#edef-OL"
(define ol (generate-html-surface-function html4:ol "ol" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DD</b> tag element which can be applied without contents (corresponding to start tag only) (definition description ). <br>
;; .form (dd . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:dd" "basis.html#html4:dd"
;; .reference "HTML documentation" "DD" "../../../html-doc/html401/struct/lists.html#edef-DD"
(define dd (generate-html-surface-function html4:dd "dd" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DT</b> tag element which can be applied without contents (corresponding to start tag only) (definition term ). <br>
;; .form (dt . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:dt" "basis.html#html4:dt"
;; .reference "HTML documentation" "DT" "../../../html-doc/html401/struct/lists.html#edef-DT"
(define dt (generate-html-surface-function html4:dt "dt" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DL</b> double tag element (definition list ). <br>
;; .form (dl . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, compact. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:dl" "basis.html#html4:dl"
;; .reference "HTML documentation" "DL" "../../../html-doc/html401/struct/lists.html#edef-DL"
(define dl (generate-html-surface-function html4:dl "dl" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>INS</b> double tag element (inserted text, deleted text ). <br>
;; .form (ins . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:ins" "basis.html#html4:ins"
;; .reference "HTML documentation" "INS" "../../../html-doc/html401/struct/text.html#edef-INS"
(define ins (generate-html-surface-function html4:ins "ins" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DEL</b> double tag element (inserted text, deleted text ). <br>
;; .form (del . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite, datetime. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:del" "basis.html#html4:del"
;; .reference "HTML documentation" "DEL" "../../../html-doc/html401/struct/text.html#edef-DEL"
(define del (generate-html-surface-function html4:del "del" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BLOCKQUOTE</b> double tag element (long quotation ). <br>
;; .form (blockquote . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:blockquote" "basis.html#html4:blockquote"
;; .reference "HTML documentation" "BLOCKQUOTE" "../../../html-doc/html401/struct/text.html#edef-BLOCKQUOTE"
(define blockquote (generate-html-surface-function html4:blockquote "blockquote" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>Q</b> double tag element (short inline quotation ). <br>
;; .form (q . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, cite. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:q" "basis.html#html4:q"
;; .reference "HTML documentation" "Q" "../../../html-doc/html401/struct/text.html#edef-Q"
(define q (generate-html-surface-function html4:q "q" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>PRE</b> double tag element (preformatted text ). <br>
;; .form (pre . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, width. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:pre" "basis.html#html4:pre"
;; .reference "HTML documentation" "PRE" "../../../html-doc/html401/struct/text.html#edef-PRE"
(define pre (generate-html-surface-function html4:pre "pre" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>H1</b> double tag element (heading ). <br>
;; .form (h1 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:h1" "basis.html#html4:h1"
;; .reference "HTML documentation" "H1" "../../../html-doc/html401/struct/global.html#edef-H1"
(define h1 (generate-html-surface-function html4:h1 "h1" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>H2</b> double tag element (heading ). <br>
;; .form (h2 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:h2" "basis.html#html4:h2"
;; .reference "HTML documentation" "H2" "../../../html-doc/html401/struct/global.html#edef-H2"
(define h2 (generate-html-surface-function html4:h2 "h2" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>H3</b> double tag element (heading ). <br>
;; .form (h3 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:h3" "basis.html#html4:h3"
;; .reference "HTML documentation" "H3" "../../../html-doc/html401/struct/global.html#edef-H3"
(define h3 (generate-html-surface-function html4:h3 "h3" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>H4</b> double tag element (heading ). <br>
;; .form (h4 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:h4" "basis.html#html4:h4"
;; .reference "HTML documentation" "H4" "../../../html-doc/html401/present/frames.html#edef-H4"
(define h4 (generate-html-surface-function html4:h4 "h4" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>H5</b> double tag element (heading ). <br>
;; .form (h5 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:h5" "basis.html#html4:h5"
;; .reference "HTML documentation" "H5" "../../../html-doc/html401/present/frames.html#edef-H5"
(define h5 (generate-html-surface-function html4:h5 "h5" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>H6</b> double tag element (heading ). <br>
;; .form (h6 . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:h6" "basis.html#html4:h6"
;; .reference "HTML documentation" "H6" "../../../html-doc/html401/present/frames.html#edef-H6"
(define h6 (generate-html-surface-function html4:h6 "h6" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>P</b> tag element which can be applied without contents (corresponding to start tag only) (paragraph ). <br>
;; .form (p . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:p" "basis.html#html4:p"
;; .reference "HTML documentation" "P" "../../../html-doc/html401/struct/text.html#edef-P"
(define p (generate-html-surface-function html4:p "p" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>HR</b> single tag element (horizontal rule ). <br>
;; .form (hr . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align, noshade, size, width. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:hr" "basis.html#html4:hr"
;; .reference "HTML documentation" "HR" "../../../html-doc/html401/present/graphics.html#edef-HR"
(define hr (generate-html-surface-function html4:hr "hr" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>APPLET</b> double tag element (Java applet ). <br>
;; .form (applet . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: width, height. <p>Optional attributes: id, class, style, title, codebase, archive, code, object, alt, name, align, hspace, vspace. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:applet" "basis.html#html4:applet"
;; .reference "HTML documentation" "APPLET" "../../../html-doc/html401/struct/objects.html#edef-APPLET"
(define applet (generate-html-surface-function html4:applet "applet" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>PARAM</b> single tag element (named property value ). <br>
;; .form (param . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: name. <p>Optional attributes: id, value, valuetype, type. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:param" "basis.html#html4:param"
;; .reference "HTML documentation" "PARAM" "../../../html-doc/html401/struct/objects.html#edef-PARAM"
(define param (generate-html-surface-function html4:param "param" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>OBJECT</b> double tag element (generic embedded object ). <br>
;; .form (object . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, declare, classid, codebase, data, type, codetype, archive, standby, height, width, usemap, name, tabindex, align, border, hspace, vspace. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:object" "basis.html#html4:object"
;; .reference "HTML documentation" "OBJECT" "../../../html-doc/html401/struct/objects.html#edef-OBJECT"
(define object (generate-html-surface-function html4:object "object" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>IMG</b> single tag element (Embedded image ). <br>
;; .form (img . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: src, alt. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, longdesc, height, width, usemap, ismap, align, border, hspace, vspace. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:img" "basis.html#html4:img"
;; .reference "HTML documentation" "IMG" "../../../html-doc/html401/struct/objects.html#edef-IMG"
(define img (generate-html-surface-function html4:img "img" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>LINK</b> single tag element (a media-independent link ). <br>
;; .form (link . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, charset, href, hreflang, type, rel, rev, media, target. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:link" "basis.html#html4:link"
;; .reference "HTML documentation" "LINK" "../../../html-doc/html401/struct/links.html#edef-LINK"
(define link (generate-html-surface-function html4:link "link" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>AREA</b> single tag element (client-side image map area ). <br>
;; .form (area . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: alt. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, shape, coords, href, target, nohref, tabindex, accesskey, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:area" "basis.html#html4:area"
;; .reference "HTML documentation" "AREA" "../../../html-doc/html401/struct/text.html#edef-AREA"
(define area (generate-html-surface-function html4:area "area" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>HTML:MAP</b> double tag element (client-side image map ). <br>
;; .form (html:map . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: name. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:map" "basis.html#html4:map"
;; .reference "HTML documentation" "HTML:MAP" "../../../html-doc/html401/struct/objects.html#edef-MAP"
(define html:map (generate-html-surface-function html4:map "html:map" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>A</b> double tag element (anchor ). <br>
;; .form (a . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, charset, type, name, href, hreflang, target, rel, rev, accesskey, shape, coords, tabindex, onfocus, onblur. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:a" "basis.html#html4:a"
;; .reference "HTML documentation" "A" "../../../html-doc/html401/struct/links.html#edef-A"
(define a (generate-html-surface-function html4:a "a" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>CENTER</b> double tag element (shorthand for DIV align=center ). <br>
;; .form (center . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:center" "basis.html#html4:center"
;; .reference "HTML documentation" "CENTER" "../../../html-doc/html401/present/graphics.html#edef-CENTER"
(define center (generate-html-surface-function html4:center "center" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DIV</b> double tag element (generic language/style container ). <br>
;; .form (div . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, align. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:div" "basis.html#html4:div"
;; .reference "HTML documentation" "DIV" "../../../html-doc/html401/struct/global.html#edef-DIV"
(define div (generate-html-surface-function html4:div "div" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>ADDRESS</b> double tag element (information on author ). <br>
;; .form (address . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:address" "basis.html#html4:address"
;; .reference "HTML documentation" "ADDRESS" "../../../html-doc/html401/struct/global.html#edef-ADDRESS"
(define address (generate-html-surface-function html4:address "address" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BODY</b> tag element which can be applied without contents (corresponding to start tag only) (document body ). <br>
;; .form (body . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup, onload, onunload, background, bgcolor, text, link, vlink, alink. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:body" "basis.html#html4:body"
;; .reference "HTML documentation" "BODY" "../../../html-doc/html401/struct/global.html#edef-BODY"
(define body (generate-html-surface-function html4:body "body" (quote possible-single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BR</b> single tag element (forced line break ). <br>
;; .form (br . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, clear. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:br" "basis.html#html4:br"
;; .reference "HTML documentation" "BR" "../../../html-doc/html401/struct/text.html#edef-BR"
(define br (generate-html-surface-function html4:br "br" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>FONT</b> double tag element (local change to font ). <br>
;; .form (font . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, size, color, face. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:font" "basis.html#html4:font"
;; .reference "HTML documentation" "FONT" "../../../html-doc/html401/present/graphics.html#edef-FONT"
(define font (generate-html-surface-function html4:font "font" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BASEFONT</b> single tag element (base font size ). <br>
;; .form (basefont . attributes)
;; .parameter attributes HTML and CSS attribute value pairs. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: size. <p>Optional attributes: id, color, face. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:basefont" "basis.html#html4:basefont"
;; .reference "HTML documentation" "BASEFONT" "../../../html-doc/html401/present/graphics.html#edef-BASEFONT"
(define basefont (generate-html-surface-function html4:basefont "basefont" (quote single)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BDO</b> double tag element (I18N BiDi over-ride ). <br>
;; .form (bdo . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc Required attributes: dir. <p>Optional attributes: id, class, style, title, lang. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:bdo" "basis.html#html4:bdo"
;; .reference "HTML documentation" "BDO" "../../../html-doc/html401/struct/dirlang.html#edef-BDO"
(define bdo (generate-html-surface-function html4:bdo "bdo" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SPAN</b> double tag element (generic language/style container ). <br>
;; .form (span . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:span" "basis.html#html4:span"
;; .reference "HTML documentation" "SPAN" "../../../html-doc/html401/struct/global.html#edef-SPAN"
(define span (generate-html-surface-function html4:span "span" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SUB</b> double tag element (subscript, superscript ). <br>
;; .form (sub . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:sub" "basis.html#html4:sub"
;; .reference "HTML documentation" "SUB" "../../../html-doc/html401/struct/text.html#edef-SUB"
(define sub (generate-html-surface-function html4:sub "sub" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SUP</b> double tag element (subscript, superscript ). <br>
;; .form (sup . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:sup" "basis.html#html4:sup"
;; .reference "HTML documentation" "SUP" "../../../html-doc/html401/struct/text.html#edef-SUP"
(define sup (generate-html-surface-function html4:sup "sup" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>TT</b> double tag element (<em>no explanation available</em>). <br>
;; .form (tt . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:tt" "basis.html#html4:tt"
;; .reference "HTML documentation" "TT" "../../../html-doc/html401/present/graphics.html#edef-TT"
(define tt (generate-html-surface-function html4:tt "tt" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>I</b> double tag element (<em>no explanation available</em>). <br>
;; .form (i . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:i" "basis.html#html4:i"
;; .reference "HTML documentation" "I" "../../../html-doc/html401/present/graphics.html#edef-I"
(define i (generate-html-surface-function html4:i "i" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>B</b> double tag element (<em>no explanation available</em>). <br>
;; .form (b . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:b" "basis.html#html4:b"
;; .reference "HTML documentation" "B" "../../../html-doc/html401/present/graphics.html#edef-B"
(define b (generate-html-surface-function html4:b "b" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>U</b> double tag element (<em>no explanation available</em>). <br>
;; .form (u . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:u" "basis.html#html4:u"
;; .reference "HTML documentation" "U" "../../../html-doc/html401/present/graphics.html#edef-U"
(define u (generate-html-surface-function html4:u "u" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>S</b> double tag element (<em>no explanation available</em>). <br>
;; .form (s . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:s" "basis.html#html4:s"
;; .reference "HTML documentation" "S" "../../../html-doc/html401/present/graphics.html#edef-S"
(define s (generate-html-surface-function html4:s "s" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>STRIKE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (strike . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:strike" "basis.html#html4:strike"
;; .reference "HTML documentation" "STRIKE" "../../../html-doc/html401/present/graphics.html#edef-STRIKE"
(define strike (generate-html-surface-function html4:strike "strike" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>BIG</b> double tag element (<em>no explanation available</em>). <br>
;; .form (big . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:big" "basis.html#html4:big"
;; .reference "HTML documentation" "BIG" "../../../html-doc/html401/present/graphics.html#edef-BIG"
(define big (generate-html-surface-function html4:big "big" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SMALL</b> double tag element (<em>no explanation available</em>). <br>
;; .form (small . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:small" "basis.html#html4:small"
;; .reference "HTML documentation" "SMALL" "../../../html-doc/html401/present/graphics.html#edef-SMALL"
(define small (generate-html-surface-function html4:small "small" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>EM</b> double tag element (<em>no explanation available</em>). <br>
;; .form (em . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:em" "basis.html#html4:em"
;; .reference "HTML documentation" "EM" "../../../html-doc/html401/struct/text.html#edef-EM"
(define em (generate-html-surface-function html4:em "em" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>STRONG</b> double tag element (<em>no explanation available</em>). <br>
;; .form (strong . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:strong" "basis.html#html4:strong"
;; .reference "HTML documentation" "STRONG" "../../../html-doc/html401/struct/text.html#edef-STRONG"
(define strong (generate-html-surface-function html4:strong "strong" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>DFN</b> double tag element (<em>no explanation available</em>). <br>
;; .form (dfn . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:dfn" "basis.html#html4:dfn"
;; .reference "HTML documentation" "DFN" "../../../html-doc/html401/struct/text.html#edef-DFN"
(define dfn (generate-html-surface-function html4:dfn "dfn" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>CODE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (code . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:code" "basis.html#html4:code"
;; .reference "HTML documentation" "CODE" "../../../html-doc/html401/struct/text.html#edef-CODE"
(define code (generate-html-surface-function html4:code "code" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>SAMP</b> double tag element (<em>no explanation available</em>). <br>
;; .form (samp . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:samp" "basis.html#html4:samp"
;; .reference "HTML documentation" "SAMP" "../../../html-doc/html401/struct/text.html#edef-SAMP"
(define samp (generate-html-surface-function html4:samp "samp" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>KBD</b> double tag element (<em>no explanation available</em>). <br>
;; .form (kbd . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:kbd" "basis.html#html4:kbd"
;; .reference "HTML documentation" "KBD" "../../../html-doc/html401/struct/text.html#edef-KBD"
(define kbd (generate-html-surface-function html4:kbd "kbd" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>VAR</b> double tag element (<em>no explanation available</em>). <br>
;; .form (var . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:var" "basis.html#html4:var"
;; .reference "HTML documentation" "VAR" "../../../html-doc/html401/struct/text.html#edef-VAR"
(define var (generate-html-surface-function html4:var "var" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>CITE</b> double tag element (<em>no explanation available</em>). <br>
;; .form (cite . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:cite" "basis.html#html4:cite"
;; .reference "HTML documentation" "CITE" "../../../html-doc/html401/struct/text.html#edef-CITE"
(define cite (generate-html-surface-function html4:cite "cite" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>ABBR</b> double tag element (<em>no explanation available</em>). <br>
;; .form (abbr . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:abbr" "basis.html#html4:abbr"
;; .reference "HTML documentation" "ABBR" "../../../html-doc/html401/struct/text.html#edef-ABBR"
(define abbr (generate-html-surface-function html4:abbr "abbr" (quote double)))

;; The LAML mirror of the HTML 4.0 (loose) <b>ACRONYM</b> double tag element (<em>no explanation available</em>). <br>
;; .form (acronym . attributes-and-contents)
;; .parameter attributes-and-contents HTML and CSS attribute value pairs together with a list of textual contents. Attribute names must be symbols; CSS attributes: 'css:name. Attribute values must be strings.
;; .misc No required attributes. <p>Optional attributes: id, class, style, title, lang, dir, onclick, ondblclick, onmousedown, onmouseup, onmouseover, onmousemove, onmouseout, onkeypress, onkeydown, onkeyup. <br>
;; .reference "general calling info""Manual abstract""#MANUAL-TOP"
;; .reference "similar basic form" "html4:acronym" "basis.html#html4:acronym"
;; .reference "HTML documentation" "ACRONYM" "../../../html-doc/html401/struct/text.html#edef-ACRONYM"
(define acronym (generate-html-surface-function html4:acronym "acronym" (quote double)))

