; A Leno style which makes it easier and cleaner
; to use the XML-in-LAML Leno version. This style
; takes care of style loading from the lecture-notes
; directory, and it implements all the front matters stuff.

; As of now the element handling of the front matters is primitive.
; We should move the basic element handling machinery to leno.scm in order
; to improve it.

;  ---------------------------------------------------------------------------------------------------

(if (and laml-load-variation (eq? laml-load-variation 'no-html-mirror))
    (begin #f) ; load no html mirror stuff
    (begin
      (lib-load "html4.0-loose/basis.scm")
      (lib-load "html4.0-loose/surface.scm")
      (lib-load "html4.0-loose/convenience.scm")))

; ---------------------------------------------------------------------------------------------------
; Constants
(define explicit-space #t)
(define explicit-space-suppress #f)

;; The symbolic name of explicit white space suppress
(define _ explicit-space-suppress)

; -----------------------------------------------------------------------------
(define (front:title . x) (make-element 'front:title x))
(define (front:sub-title . x) (make-element 'front:sub-title x))
(define (front:author . x) (make-element 'front:author x))
(define (front:affiliation . x) (make-element 'front:affiliation x))
(define (front:abstract . x) (make-element 'front:abstract x))

; -----------------------------------------------------------------------------
; Currently only supports relatively simple single chapter materials.
; Fixed variables due this this limiation.
(define note-source-directory (startup-directory))

(define page-name (source-filename-without-extension))

; which lecture - relevant for the author if there were more chapters
(define current-lecture 1)

; Do not show lecture numbers - there is only one
(define lecture-number #f)

(define (cross-reference-location-hints location-list)  ; No location hints 
  "")

(define (meta-tag-clauses)
   (list (list 'HTTP-EQUIV "Content-Type" 'content "text/html; charset = ISO-8859-1")  
         (list 'name "Generator" 'content "LAML")
         (list 'name "description" 
                     'lang (meta-language language-preference)
                     'content note-contents-description)
   )
)

(define front-index? #f)  ; No front index; not needed because there is only one chaper.

(define note-abstract "")

; ---------------------------------------------------------------------------

; A variable in which we capture the front matters stuff - intended for xml reverse enginering
(define leno-front-matters-element #f)

(define (leno-front-matters . p)
  (let ((cont-attr (sort-element-parameters p 'leno-front-matters)))
   (set! leno-front-matters-element 
        (make-element-structure 
	 'leno-front-matters
	 (car cont-attr)
	 (propertylist-to-alist (cdr cont-attr)))))
 
  (let ((get-constituent 
          (lambda (tag-name) 
            (let ((res (find-in-list (lambda (y) (and (element-structure? y) (eq? (new-element-tag y) tag-name))) p)))
              (if res (aggregated-contents (new-element-contents res)) #f))))  ; car too simple

        (get-attribute
          (lambda (tag-name)
            (let ((res (memq tag-name p)))
              (if res (cadr res) #f))))

        (global-define (lambda (symbol expr) (eval (list 'define symbol expr))))

        (boolean-value-of 
          (lambda (x) (cond ((equal? (downcase-string x) "true") #t)
                            ((equal? (downcase-string x) "false") #f)
                            (else (laml-error "Unknown boolean val: " x)))))
        
       )
   (let* ((title-constituent (get-constituent 'front:title))
          (sub-title-constituent (get-constituent 'front:sub-title))
          (author-constituent (get-constituent 'front:author))
          (affiliation-constituent (get-constituent 'front:affiliation))  ; perhaps support more of these
          (abstract-constituent (get-constituent 'front:abstract))

          (scheme-prefix (get-attribute 'scheme-prefix))
          (scheme-suffix (get-attribute 'scheme-suffix))

          (course-home-url-attr (get-attribute 'course-home-url))
          (author-home-url-attr (get-attribute 'author-home-url))
          (note-download-url-attr (get-attribute 'note-download-url))

          (note-contents-description-attr (get-attribute 'note-contents-description))
          (slide-header-attr (get-attribute 'slide-header))
          (trail-of-lecture-attr (get-attribute 'trail-of-lecture))
          (language-attr (get-attribute 'language))
          (show-and-speak-attr (get-attribute 'show-and-speak))
            (default-showing-time-attr (get-attribute 'default-showing-time))
            (additional-showing-time-attr (get-attribute 'additional-showing-time))
            (sound-source-attr (get-attribute 'sound-source))
            (speak-url-prefix-attr (get-attribute 'speak-url-prefix))
          (exercise-model-attr (get-attribute 'exercise-model))
          (mouse-advancement-attr (get-attribute 'mouse-advancement))
          (word-index-attr (get-attribute 'word-index))
          (apply-css-styling-attr (get-attribute 'apply-css-styling))
          (logo-url-attr (get-attribute 'logo-url))   
          (news-flash-string-attr (get-attribute 'news-flash-string))
            (news-flash-level-attr (get-attribute 'news-flash-level))
          (quiz-support-attr (get-attribute 'quiz-support))
          (lecture-note-verbosity-level (get-attribute 'verbosity-level))
 
         )

     (if scheme-prefix
         (load (string-append note-source-directory scheme-prefix)))

     (global-define 'lecture-sections `(list (list ,page-name ,title-constituent)))
     (global-define 'notes-title title-constituent)
     (global-define 'note-contents-description note-contents-description-attr)
     (global-define 'course-home-url course-home-url-attr)
     (global-define 'author-home-url author-home-url-attr)
     (global-define 'note-download-url note-download-url-attr)


  
     (laml-style "lecture-notes/lecture-notes-1")

     (if scheme-suffix
         (load (string-append note-source-directory scheme-suffix)))

     (if slide-header-attr (set! slide-header? (as-symbol slide-header-attr)))
     (if trail-of-lecture-attr (set! trail-of-lecture? (boolean-value-of trail-of-lecture-attr)))
     (if language-attr (set! language-preference (as-symbol language-attr)))

     (if show-and-speak-attr 
        (begin
          (if show-and-speak-attr (set! show-and-speak? (boolean-value-of show-and-speak-attr)))
          (if default-showing-time-attr (set! default-showing-time (as-number default-showing-time-attr)))
          (if additional-showing-time-attr (set! additional-showing-time (as-number additional-showing-time-attr)))
          (if sound-source-attr (set! sound-source (as-symbol sound-source-attr)))
          (if speak-url-prefix-attr (set! speak-url-prefix speak-url-prefix-attr))
        )
     )
 

     (set! lecture-title title-constituent)
     (set! lecture-author-info (list (copyright-owner author-constituent) affiliation-constituent))
     (set! lecture-abstract abstract-constituent)    
     (if exercise-model-attr (exercise-model (as-symbol exercise-model-attr)))
     (if mouse-advancement-attr (set! mouse-advancement (as-symbol mouse-advancement-attr)))
     (if word-index-attr (if (boolean-value-of word-index-attr) (include-word-index) (exclude-word-index)))
     (if apply-css-styling-attr
        (begin
          (set! apply-css-styling? (boolean-value-of apply-css-styling-attr))
        )
     )
     (if quiz-support-attr (set! quiz-support? (boolean-value-of quiz-support-attr)))
     (if news-flash-string-attr (set! news-flash-string news-flash-string-attr))
     (if news-flash-level-attr (set! news-flash-level (as-number news-flash-level-attr)))
     (if logo-url-attr (set! logo-url logo-url-attr))
     (if (and lecture-note-verbosity-level (numeric-string? lecture-note-verbosity-level))
         (set! lecture-note-verbose-mode (as-number lecture-note-verbosity-level)))
     

   )
  )
)

; ---------------------------------------------------------------------------------------------------------------
; The new element stuff
; Underlying element machinery:

; High level element constructor which 'sorts' the elemnet parameters.
(define (make-element name rest)
 (let* ((contents-attributes (sort-element-parameters rest name))
	(contents (car contents-attributes))
	(attributes (propertylist-to-alist (cdr contents-attributes))) ; the mirror delives a property list
       )
  (let ((es (make-element-structure name contents attributes)))
    (check-element! es)
    es)))

; Check that the element structure  is valid.
; Stop the program if not.
(define (check-element! es)
  #t)


; Low level element contructor.
; Make a normalized element structure (list). Name is the name of the element (either a string or symbol).
; contents is a list of contents forms, each on normalize form.
; attributes is an association list of attributes (key value pairs).
(define (make-element-structure name contents attributes)
  (list 'element name contents attributes))

; Is x an element structure.
(define (element-structure? x)
  (and (list? x) (= (length x) 4) (eq? (car x) 'element)))

; Element selector functions 
(define new-element-tag second)
(define new-element-contents third)
(define new-element-attributes fourth)


(define (aggregated-contents contents-list)
  (aggregated-contents-1 contents-list ""))

(define (aggregated-contents-1 contents-list res)
  (cond ((null? contents-list) res)
        ((cdata? (car contents-list)) 
           (aggregated-contents-1 (cdr contents-list) (string-append res (car contents-list))))
        ((forced-white-space? (car contents-list)) (aggregated-contents-1 (cdr contents-list) (string-append res " ")))
        ((element-structure? (car contents-list)) ; pertaining to HTML elements in LENO XML elements
           (aggregated-contents-1 (cdr contents-list) (string-append res (html-render (car contents-list)))))))



; -----------------------------------------------------------------------------
; The XML-in-LAML parameter handling - inspired by the HTML4.0 surface mirror.

(define (sort-element-parameters parameters tag-name)
 (sort-element-parameters-1 parameters parameters '() '() tag-name))

(define (sort-element-parameters-1 original-parameters parameters contents attributes tag-name)
 (letrec ((strip-initial-explicit-spaces 
	   (lambda (cl) (if (and (pair? cl) (eq? (car cl) explicit-space)) (strip-initial-explicit-spaces (cdr cl)) cl)))
          (ast? element-structure?)
          (cdata? string?)
          (contents-data? (lambda (x) (or (cdata? x) (ast? x))))
	  (list-non-ast? (lambda (x) (and (list? x) (not (ast? x)))))
         )
  (cond ((null? parameters) (cons (reverse (strip-initial-explicit-spaces contents)) (reverse attributes)))

        ; CONTENTS DATA -  no space after
        ((and (contents-data? (car parameters)) (not (null? (cdr parameters)))
              (boolean? (cadr parameters)) (not (cadr parameters)))              
                 (sort-element-parameters-1 original-parameters (cddr parameters) (cons (car parameters) contents) attributes tag-name))

        ; CONTENTS DATA -  space after
        ((and (contents-data? (car parameters)) (not (null? (cdr parameters)))
              (boolean? (cadr parameters)) (cadr parameters))                    ; space after
                 (sort-element-parameters-1 original-parameters
                                        (cddr parameters) (cons explicit-space (cons (car parameters) contents)) attributes tag-name))

        ; CONTENTS DATA -  space after
        ((contents-data? (car parameters))   ; space after
                 (sort-element-parameters-1 original-parameters 
                                        (cdr parameters) (cons explicit-space (cons (car parameters) contents)) attributes tag-name))


        ; LIST - no space after
        ((and (list-non-ast? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters)) (not (cadr parameters)))
           (let* ((rec-res (sort-element-parameters-1 original-parameters (car parameters) '() '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )  
              (sort-element-parameters-1 original-parameters
                                        (cddr parameters) 
                                        (append (reverse rec-contents) contents) (append (reverse rec-attributes) attributes) tag-name)))

        ; LIST - space after
        ((and (list-non-ast? (car parameters)) (not (null? (cdr parameters))) (boolean? (cadr parameters))  (cadr parameters))
           (let* ((rec-res (sort-element-parameters-1 original-parameters (car parameters) '() '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 )  
              (sort-element-parameters-1 original-parameters
                                        (cddr parameters) 
                                        (append (list explicit-space) (reverse rec-contents) contents) 
                                        (append (reverse rec-attributes) attributes) tag-name)))

        ; LIST - space after
        ((and (list-non-ast? (car parameters)))
           (let* ((rec-res (sort-element-parameters-1 original-parameters (car parameters) '() '() tag-name))
                  (rec-contents (car rec-res))
		  (rec-attributes (cdr rec-res)) ; reversed
                 ) 
              (sort-element-parameters-1 original-parameters
                                        (cdr parameters) 
                                        (append (list explicit-space)
                                                (reverse rec-contents)
                                                contents)
                                        (append (reverse rec-attributes) attributes) tag-name)))

        ; SYMBOL - attribute name 
        ((and (symbol? (car parameters)) (not (null? (cdr parameters))) (not (boolean? (cadr parameters))))
           (let ((attr-name (car parameters))
                 (attr-val (cadr parameters)))
             (sort-element-parameters-1 original-parameters (cddr parameters) contents (cons attr-val (cons attr-name attributes)) tag-name)))

        ; SYMBOL - error
        ((symbol? (car parameters)) (sort-error (string-append "Attributes of the " tag-name
                                    " tag must be of the form 'symbol \"value\". Only the symbol " (as-string (car parameters))
                                    " appears in last attribute") original-parameters))

        (else (sort-error (string-append "Error in an LAML " tag-name " tag.") original-parameters))
  )))

(define (sort-error message parameters)
 (let* ((max-str-lgt 80)  ; symbolic constant definition
        (parameters-1 (as-quoted-string parameters))
        (parameters-2 (if (> (string-length parameters-1) max-str-lgt) 
                        (string-append (substring parameters-1 0 (- max-str-lgt 1)) "...")
                        parameters-1)))
  (error
    (string-append
      message (as-string #\newline)
      "  FORM CONTENTS AND ATTR.: " parameters-2 (as-string #\newline)))))

(define (forced-white-space? x)
 (and (boolean? x) x))

(define white-space-related? boolean?)

(define cdata? string?)



; ---------------------------------------------------------------------------------------------------------------
; This procedure is called by tool procedure leno-xml in laml.scm.
; Handling of element structure from Leno-XML: The XML interface to LENO.
; Extracts front matters stuff and the note page elements, and processes these.
; Assume as a precondition that the structure of the parsed XML document is valid.
(define (leno-xml-process element-str)
 (let* ((leno-subelements (new-element-contents element-str))
        (front-matter-element 
          (find-in-list (lambda (el) (eq? 'leno-front-matters (new-element-tag el))) leno-subelements))
        (front-matter-list (make-front-matter-list front-matter-element))
        (note-page-list 
          (filter (lambda (el) (eq? 'note-page (new-element-tag el))) leno-subelements))
       )
   (apply leno-front-matters front-matter-list)
   (begin-notes)
   (for-each 
     proces-note-page-element 
     note-page-list)
   (end-notes)))


(define (proces-note-page-element note-page-element)
  (let* ((note-page-id (as-symbol (get 'id (new-element-attributes note-page-element))))
	 (new-style-elements (filter (compose not forced-white-space?) (new-element-contents note-page-element)))
	 (new-style-attributes (new-element-attributes note-page-element)) ; not used
	 (old-style-elements (map new-style-element-to-old-style-element new-style-elements))
	)
    (set! new-note-page-list (cons note-page-element new-note-page-list))
    (apply original-note-page (cons note-page-id old-style-elements))))


(define (make-front-matter-list front-matter-element)
  (let ((contents-list (new-element-contents front-matter-element))
        (attr-list (new-element-attributes front-matter-element)))
   (append
    contents-list
    (alist-to-propertylist attr-list))))





